/** BEGIN COPYRIGHT BLOCK
 * Copyright (C) 2001 Sun Microsystems, Inc.  Used by permission.
 * Copyright (C) 2005 Red Hat, Inc.
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * END COPYRIGHT BLOCK **/
/*********************************************************************
**
** NAME:
**   ux-remove.cc
**
** DESCRIPTION:
**   Administration Server Uninstall program
**
** NOTES:
** This program is intended to be UNIX-only, and not thread safe.
** Derived from the original ux-config.c with UI moved to ux-config.cc
**
**
*********************************************************************/

extern "C"
{
#include <stdio.h>		/* printf, file I/O */
#include <sys/stat.h>
#include <string.h>
#include <strings.h>
#include <signal.h>		/* kill() */
}

#include "global.h"
#include "ux-util.h"
#include "ldapu.h"

int main(int argc, char *argv[])
{
  NSString serverRoot;
  NSString admConfFile;
  NVPair *admConf;
  InstallInfo *uninstallInfo;
  char *infoFile;
  const char *ldapURL;
  const char *sieDN;
  const char *isieDN;
  const char *siePwd;
  /*const char *adminPwd;*/
  int opt;
  int err;
  char temp[MED_BUF];
  struct stat fi;

  while ((opt = getopt(argc, argv, "f:")) != EOF)
  {
    switch (opt)
	  {
	    case 'f':
	      infoFile = strdup(optarg);
	      uninstallInfo = new InstallInfo(infoFile);
        uninstallInfo->toUTF8();
        break;
	    default:
	      break;
	  }
  }
  if (infoFile == NULL || uninstallInfo == NULL ||
      uninstallInfo->isEmpty() == True)
  {
     printf("[Admin] Answer cache not found\n");
     err = -1;
  }
  else
  {
     serverRoot = uninstallInfo->get(SERVER_ROOT);

     ldapURL = uninstallInfo->get(CONFIG_LDAP_URL);
     /* Use admin id and admin pwd to authenticate against DS */
     sieDN = uninstallInfo->get(MC_ADMIN_ID);
     siePwd = uninstallInfo->get(MC_ADMIN_PWD);
      
     if (ldapURL == NULL || sieDN == NULL)
     {
       printf("[Admin] LDAP information not found\n");
       err = -1;
     }
     else
     {
       LdapError ldapError;
       Ldap ldap(ldapError, ldapURL, sieDN, siePwd, sieDN, siePwd);

       if (ldapError != OKAY)
       {
         /* remove the message which causes confusion when DS is down
            sprintf(temp, "%ld", ldapError.errorCode());
            printf("[Admin] Ldap authentication failed (%s:%s)\n", temp, ldapError.msg()),
          */
         err = -1;
       }
       else
       {
         ldapError = removeSIE(&ldap, sieDN, True);
         if (ldapError != OKAY)
         {
           /* remove the message which causes confusion when DS is down
             sprintf(temp, "%ld", ldapError.errorCode());
             printf("[Admin] Cannot remove Admin server instance (%s)\n", temp);
           */
         }
       }
     }
   }

   char pidFile[BIG_BUF];
   char stopProgram[BIG_BUF];
   int  pid;
   FILE *fhdl = NULL;

   /* Stop the Admin Server */
   snprintf(pidFile, sizeof(pidFile), "%s/admin-serv/logs/pid", serverRoot.data());
   pidFile[sizeof(pidFile)-1] = 0;
   if (stat(pidFile, &fi) == 0)
   {
      snprintf(stopProgram, sizeof(stopProgram), "%s/stop-admin", serverRoot.data());
      stopProgram[sizeof(stopProgram)-1] = 0;
      if (stat (stopProgram, &fi) != 0)
      {
         snprintf(stopProgram, sizeof(stopProgram), "kill `cat %s`", pid);
         stopProgram[sizeof(stopProgram)-1] = 0;
      }
      system(stopProgram);
   }

   /* Stop SNMP Master Agent if running */
   snprintf(pidFile, sizeof(pidFile), "%s/admin-serv/logs/pid_masteragt", serverRoot.data());
   pidFile[sizeof(pidFile)-1] = 0;
   if ((fhdl = fopen(pidFile, "r")) != NULL)
   {
      fscanf(fhdl, "%d\n", &pid);
      fclose(fhdl);
      kill(pid, SIGKILL);
      unlink(pidFile);
   }
   
   char szCmdBuf[BIG_BUF];
   char *szHomeDir;

   szHomeDir = getenv("home");
   if(szHomeDir != NULL)
   {
      snprintf(szCmdBuf, sizeof(szCmdBuf), "rm -fr %s/.mcc", szHomeDir);
      szCmdBuf[sizeof(szCmdBuf)-1] = 0;
      
      system(szCmdBuf);
   }

   /* Remove dynamic and temporary files */
   snprintf(szCmdBuf, sizeof(szCmdBuf), "rm -fr %s/admin-serv/tmp", serverRoot.data());
   szCmdBuf[sizeof(szCmdBuf)-1] = 0;
   system(szCmdBuf);
    
   snprintf(szCmdBuf, sizeof(szCmdBuf), "rm -fr %s/admin-serv/ClassCache", serverRoot.data());
   szCmdBuf[sizeof(szCmdBuf)-1] = 0;
   system(szCmdBuf);
    
   snprintf(szCmdBuf, sizeof(szCmdBuf), "rm -fr %s/admin-serv/SessionData", serverRoot.data());
   szCmdBuf[sizeof(szCmdBuf)-1] = 0;
   system(szCmdBuf);
    
   snprintf(szCmdBuf, sizeof(szCmdBuf), "rm -fr %s/admin-serv/config/*.properties", serverRoot.data());
   szCmdBuf[sizeof(szCmdBuf)-1] = 0;
   system(szCmdBuf);

   snprintf(szCmdBuf, sizeof(szCmdBuf), "rm -fr %s/java/jars/*.icon", serverRoot.data());
   szCmdBuf[sizeof(szCmdBuf)-1] = 0;
   system(szCmdBuf);

   snprintf(szCmdBuf, sizeof(szCmdBuf), "rm -fr %s/java/.java", serverRoot.data());
   szCmdBuf[sizeof(szCmdBuf)-1] = 0;
   system(szCmdBuf);

   return 0;
}
